==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QActionEvent_shell.cpp <==
#include "QActionEvent_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
class QAction;

void deleter_QActionEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QActionEvent")
    QActionEvent *_ptr = reinterpret_cast<QActionEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QActionEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QActionEvent_shell) ); }

jmethodID QActionEvent_shell::__shell_javaMethod(int pos) const { return QActionEvent_shell::__shell()->javaMethod(typeid(QActionEvent), pos); }

// emitting (writeShellConstructor)
QActionEvent_shell::QActionEvent_shell(int type0, QAction* action1, QAction* before2)
    : QActionEvent(type0, action1, before2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QActionEvent::QActionEvent_shell(int type0, QAction* action1, QAction* before2)", QActionEvent_shell::__shell())
    QActionEvent_shell::__shell()->constructed(typeid(QActionEvent));
}

// emitting (writeShellDestructor)
QActionEvent_shell::~QActionEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QActionEvent::~QActionEvent()", QActionEvent_shell::__shell())
    QActionEvent_shell::__shell()->destructed(typeid(QActionEvent));
}

void QActionEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QActionEvent_shell*>(ptr)->QActionEvent_shell::__shell()->tryDeleteShell(typeid(QActionEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QActionEvent(int,QAction*,QAction*)
void __qt_construct_QActionEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QActionEvent(int,QAction*,QAction*)")
    jint type0 = __java_arguments[0].i;
    Q_UNUSED(type0)
    jobject action1 = __java_arguments[1].l;
    QAction* __qt_action1 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, action1));
    QActionEvent *__qt_this = new(__qtjambi_ptr) QActionEvent_shell(static_cast<int>(type0), __qt_action1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QActionEvent(int,QAction*,QAction*)
void __qt_construct_QActionEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QActionEvent(int,QAction*,QAction*)")
    jint type0 = __java_arguments[0].i;
    Q_UNUSED(type0)
    jobject action1 = __java_arguments[1].l;
    QAction* __qt_action1 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, action1));
    jobject before2 = __java_arguments[2].l;
    QAction* __qt_before2 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, before2));
    QActionEvent *__qt_this = new(__qtjambi_ptr) QActionEvent_shell(static_cast<int>(type0), __qt_action1, __qt_before2);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QActionEvent_shell
void __qt_destruct_QActionEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QActionEvent")
    reinterpret_cast<QActionEvent_shell*>(ptr)->~QActionEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QActionEvent::QActionEvent(int,QAction*,QAction*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_initialize_1native__Lio_qt_gui_QActionEvent_2ILio_qt_widgets_QAction_2Lio_qt_widgets_QAction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint type0,
 jobject action1,
 jobject before2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QActionEvent::QActionEvent(int,QAction*,QAction*)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = type0;
        arguments[1].l = action1;
        arguments[2].l = before2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QActionEvent_1, sizeof(QActionEvent_shell), typeid(QActionEvent), true, &deleter_QActionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QActionEvent::action()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_action_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QActionEvent::action()const", __qt_this)
        QAction* __qt_return_value = __qt_this->action();
        __java_return_value = QtJambiAPI::convertQObjectToJavaObject(__jni_env, __qt_return_value, "io/qt/widgets/QAction");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QActionEvent::before()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_before_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QActionEvent::before()const", __qt_this)
        QAction* __qt_return_value = __qt_this->before();
        __java_return_value = QtJambiAPI::convertQObjectToJavaObject(__jni_env, __qt_return_value, "io/qt/widgets/QAction");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QActionEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QActionEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QActionEvent>("QActionEvent", "io/qt/gui/QActionEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QActionEvent, {
        ConstructorInfo(&__qt_construct_QActionEvent_0, "ILio/qt/widgets/QAction;")
       ,ConstructorInfo(&__qt_construct_QActionEvent_1, "ILio/qt/widgets/QAction;Lio/qt/widgets/QAction;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QActionEvent);
    registerSizeOfShell(typeId, sizeof(QActionEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QActionEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QActionEvent_shell.cpp <==
#include "QActionEvent_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
class QAction;

void deleter_QActionEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QActionEvent")
    QActionEvent *_ptr = reinterpret_cast<QActionEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QActionEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QActionEvent_shell) ); }

jmethodID QActionEvent_shell::__shell_javaMethod(int pos) const { return QActionEvent_shell::__shell()->javaMethod(typeid(QActionEvent), pos); }

// emitting (writeShellConstructor)
QActionEvent_shell::QActionEvent_shell(const QActionEvent& other0)
    : QActionEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QActionEvent::QActionEvent_shell(const QActionEvent& other0)", QActionEvent_shell::__shell())
    QActionEvent_shell::__shell()->constructed(typeid(QActionEvent));
}

QActionEvent_shell::QActionEvent_shell(int type0, QAction* action1, QAction* before2)
    : QActionEvent(type0, action1, before2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QActionEvent::QActionEvent_shell(int type0, QAction* action1, QAction* before2)", QActionEvent_shell::__shell())
    QActionEvent_shell::__shell()->constructed(typeid(QActionEvent));
}

// emitting (writeShellDestructor)
QActionEvent_shell::~QActionEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QActionEvent::~QActionEvent()", QActionEvent_shell::__shell())
    QActionEvent_shell::__shell()->destructed(typeid(QActionEvent));
}

void QActionEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QActionEvent_shell*>(ptr)->QActionEvent_shell::__shell()->tryDeleteShell(typeid(QActionEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QActionEvent(QActionEvent)
void __qt_construct_QActionEvent_cref_QActionEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QActionEvent(QActionEvent)")
    jobject other0 = __java_arguments[0].l;
    const QActionEvent& __qt_other0 = qtjambi_cast<const QActionEvent& >(__jni_env, other0);
    QActionEvent *__qt_this = new(__qtjambi_ptr) QActionEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QActionEvent::QActionEvent(QActionEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_initialize_1native__Lio_qt_gui_QActionEvent_2Lio_qt_gui_QActionEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QActionEvent::QActionEvent(QActionEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QActionEvent_cref_QActionEvent, sizeof(QActionEvent_shell), typeid(QActionEvent), true, &deleter_QActionEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QActionEvent(int,QAction*,QAction*)
void __qt_construct_QActionEvent_int_QAction_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QActionEvent(int,QAction*,QAction*)")
    jint type0 = __java_arguments[0].i;
    Q_UNUSED(type0)
    jobject action1 = __java_arguments[1].l;
    QAction* __qt_action1 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, action1));
    QActionEvent *__qt_this = new(__qtjambi_ptr) QActionEvent_shell(static_cast<int>(type0), __qt_action1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QActionEvent(int,QAction*,QAction*)
void __qt_construct_QActionEvent_int_QAction_ptr_QAction_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QActionEvent(int,QAction*,QAction*)")
    jint type0 = __java_arguments[0].i;
    Q_UNUSED(type0)
    jobject action1 = __java_arguments[1].l;
    QAction* __qt_action1 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, action1));
    jobject before2 = __java_arguments[2].l;
    QAction* __qt_before2 = static_cast<QAction*>(QtJambiAPI::convertJavaObjectToQObject(__jni_env, before2));
    QActionEvent *__qt_this = new(__qtjambi_ptr) QActionEvent_shell(static_cast<int>(type0), __qt_action1, __qt_before2);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QActionEvent::QActionEvent(int,QAction*,QAction*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_initialize_1native__Lio_qt_gui_QActionEvent_2ILio_qt_widgets_QAction_2Lio_qt_widgets_QAction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint type0,
 jobject action1,
 jobject before2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QActionEvent::QActionEvent(int,QAction*,QAction*)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = type0;
        arguments[1].l = action1;
        arguments[2].l = before2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QActionEvent_int_QAction_ptr_QAction_ptr, sizeof(QActionEvent_shell), typeid(QActionEvent), true, &deleter_QActionEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QActionEvent_shell
void __qt_destruct_QActionEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QActionEvent")
    reinterpret_cast<QActionEvent_shell*>(ptr)->~QActionEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QActionEvent::action()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_action_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QActionEvent::action()const", __qt_this)
        QAction* __qt_return_value = __qt_this->action();
        __java_return_value = QtJambiAPI::convertQObjectToJavaObject(__jni_env, __qt_return_value, "io/qt/widgets/QAction");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QActionEvent::before()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_before_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QActionEvent::before()const", __qt_this)
        QAction* __qt_return_value = __qt_this->before();
        __java_return_value = QtJambiAPI::convertQObjectToJavaObject(__jni_env, __qt_return_value, "io/qt/widgets/QAction");
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QActionEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QActionEvent *__qt_this = QtJambiAPI::objectFromNativeId<QActionEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QActionEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QActionEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QActionEvent>("QActionEvent", "io/qt/gui/QActionEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QActionEvent, {
        ConstructorInfo(&__qt_construct_QActionEvent_cref_QActionEvent, "Lio/qt/gui/QActionEvent;")
       ,ConstructorInfo(&__qt_construct_QActionEvent_int_QAction_ptr, "ILio/qt/widgets/QAction;")
       ,ConstructorInfo(&__qt_construct_QActionEvent_int_QAction_ptr_QAction_ptr, "ILio/qt/widgets/QAction;Lio/qt/widgets/QAction;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QActionEvent);
    registerSizeOfShell(typeId, sizeof(QActionEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QActionEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
